<p align="center">
  <img src="https://raw.githubusercontent.com/sandy98/oxi/main/static/img/oxi_1_rounded.jpg" alt="Oxi Logo" width="125px" />

</p>

<h1 align="center">Oxi</h1>

ASGI Full Stack:

* Web Server
* Web App

...and yes, Oxi is a cutie faithful dog!

#### Install

```
pip install oxi
```

#### Usage

`python3 -m oxi`

The latter works serving static files/directories in the same vein that Python's standard library 

`python3 -m http.server`

does.


But there's a lot more coming soon...
